function [classifyResultONE, ecgcorrelation,QRS,ecgmean] = challenge(recordName)

% addpath './QRS_detection/'

% Sample entry for the 2017 PhysioNet/CinC Challenge.
%
% INPUTS:
% recordName: string specifying the record name to process
%
% OUTPUTS:
% classifyResult: integer value where
%                     N = normal rhythm
%                     A = AF
%                     O = other rhythm
%                     ~ = noisy recording (poor signal quality)
%
% To run your entry on the entire training set in a format that is
% compatible with PhysioNet's scoring enviroment, run the script
% generateValidationSet.m
%
% The challenge function requires that you have downloaded the challenge
% data 'training_set' in a subdirectory of the current directory.
%    http://physionet.org/physiobank/database/challenge/2017/
%
% This dataset is used by the generateValidationSet.m script to create
% the annotations on your training set that will be used to verify that
% your entry works properly in the PhysioNet testing environment.
%
%
% Version 1.0
%
%
% Written by: Chengyu Liu and Qiao Li January 20 2017
%             chengyu.liu@emory.edu  qiao.li@emory.edu
%
% Last modified by: Ania 25.05 
%
%
classifyResultONE = 'N'; % default output normal rhythm

%% AF determination
[~,ecg,fs,~] = rdmat(recordName);
ecg = ecg';
 % falki 
Y = upcoef('d',ecg,'db6',2);
ecg_falkowe = Y(1:4:end);
[QRS_donoise] = hybrid_detection(ecg, fs);
[QRS] = hybrid_detection(ecg_falkowe, fs);
 
%% - mean beat
[noise,ecgcorrelation,QRS,ecgmean] = noiseDetector2(ecg', QRS_donoise, fs);

if noise == 1
    classifyResultONE = '~';
else
    if length(QRS)<6
        classifyResultONE = '~';
    else
        RR = diff(QRS')/fs;
        
        isOther = checkOtherPreliminary_v2(ecg,QRS,fs);
        
        if isOther == 1
            classifyResultONE = 'O';
        else
        
            % feature extraction:
        
            % podwajanie wektora RR dla krotkich sygnalow dla AFEv
            RR_dla_AFEv = RR;
            if length(ecg)/fs < 29
                RR_dla_AFEv = [RR; RR];
            end
            
            % cechy pierwotne przerobione na filozofie Jacka (25)
            [features_AF] = comput_AFEv(RR_dla_AFEv);

            % linecross (Poincare crossing) Jacka i Ani (2)
            [feature_x, feature_xm] = line_cross(QRS, fs);

            % 25 prostych cech Lepka
            features_lepek = lepeksGreaterSetOfFeatures2(RR);
        
            % nowe cechy Ani i Jacka:
            
            % polelipsy Poincare i wskazniki PNN (6)
            features_jacek = moreSimpleFeaturesByJack(RR);
         
            % sample entropy of RR (5)
            [features_sampen_rr,~] = sampen(RR,5,0.2,1,0,0);
         
            % cechy na podstawie zalamka P (prawd. slabo dopracowane) (5)
            %[mean_amp_abs, mean_amp, dif_front, sum_front_std, r_steepnes] = Pwave(ecg, QRS, fs);
            %features_Pwave = [mean_amp_abs, mean_amp, dif_front, sum_front_std, r_steepnes];
         
            % Pwave_clear
            [mean_amp_abs, mean_amp, dif_front, sum_front_std_av, sum_front_std_av_full, r_steepnes, dynamics, field ] = Pwave_clear(ecg, QRS, fs);
            features_Pwave = [mean_amp_abs, mean_amp, dif_front, sum_front_std_av, sum_front_std_av_full, r_steepnes, dynamics, field];
         
            % Pwave_clear_advanced
            [mean_amp_abs2, mean_amp2, dif_front2, sum_front_std_av2, sum_front_std_av_full2, dynamics2, field2 ] = Pwave_clear_advanced(ecg, QRS, fs);
            features_Pwave_advanced = [mean_amp_abs2, mean_amp2, dif_front2, sum_front_std_av2, sum_front_std_av_full2, dynamics2, field2];
         
         
            features = [features_AF feature_x feature_xm features_lepek ...
                features_jacek features_sampen_rr'  features_Pwave features_Pwave_advanced ];
            
            % joining
            %features = [features_AF feature_x feature_xm features_lepek ...
            %            features_jacek features_sampen_rr'  features_Pwave];
            
            % classification by NN
            classifyResultONE = nn2(features);
            
        end
    end
end
%% You can add the determination rules for other rhythm and noisy recordings here

