function [x, xm] = line_cross(peaks, fs)
%LINE_CROSS - for Poincare plots, counts percent of significant crossings
% through equal RR line; two new features for AF detection
% Input:
% peaks - detected R peaks
% fs - sampling frequency
% Output:
% x - percent of significant crossings through equal RR line
% xm - percent of significant crossings through equal RR line to all RR
% by Jacek
% Last modification: 06.04.17

    RR = diff(peaks')/fs*1000;
    big = 0;
    tot = 0;
    for i = 1 : length(RR)-2
        
        if((RR(i) > RR(i+1) && RR(i+1) < RR(i+2)) || ...
           (RR(i) < RR(i+1) && RR(i+1) > RR(i+2)))
            
            a = RR(i)-RR(i+1);
            b = RR(i+1)-RR(i+2);
            dist = sqrt(a^2 + b^2);
            if dist > 60 %FIXME: check it
                big = big+1;
            end
            tot = tot + 1;
        end
    end
    
    x = (big/tot)*100;
    xm = tot/(length(RR)-2)*100; 

end

